@@ -6,7 +6,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2017-2023 Univention GmbH
+# Copyright 2017-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -158,7 +158,7 @@ class HTML:
             r.pop('_links', None)
             r.pop('_embedded', None)
             if r:
-                pre = ET.Element("pre")
+                pre = ET.Element("script", type='application/json')
                 pre.text = json.dumps(r, indent=4)
                 root.append(pre)
 
