@@ -44,8 +44,8 @@ from univention.admin.rest.sanitizer import (
     Param, StringSanitizer,
 )
 from univention.admin.rest.utils import NotFound, superordinate_names
+from univention.config_registry import ucr
 from univention.lib.i18n import Translation
-from univention.management.console.config import ucr
 from univention.management.console.modules.udm.udm_ldap import UDM_Module
 
 
@@ -1034,6 +1034,7 @@ class _OpenAPIBase:
             },
             'security': [{
                 "basic": [],
+                # "bearer": [],  # FIXME: /univention/components/python-udm-rest-api-client#25
             }],
             'tags': openapi_tags,
             'components': {
@@ -1044,6 +1045,10 @@ class _OpenAPIBase:
                         'scheme': 'basic',
                         'type': 'http',
                     },
+                    # 'bearer': {  # FIXME: /univention/components/python-udm-rest-api-client#25
+                    #     'scheme': 'bearer',
+                    #     'type': 'http',
+                    # },
                 },
                 'parameters': openapi_parameters,  # Reusable path, query, header and cookie parameters
                 'responses': openapi_responses,
